@@ -40,6 +40,7 @@ class genetic_data_handler:
 
 
 
+
     def get_subject_ids(self):
         """
         A utility function which lets user fetch numpy array containing the list of all subject ids
@@ -107,7 +108,7 @@ class genetic_data_handler:
                                          genetic_data_path + "bim_files/" + "ukb_snp_chr" + chr_num + "_v2.bim",
                                          genetic_data_path + "fam_files/" + "ukb22418_c" + chr_num + "_b0_v2_s488176.fam",verbose=True)
             genetic_df = genetic_df.set_index({"variant": "snp"})
-            temp_output = temp_output=genetic_df.head(num_subjects)
+            temp_output=genetic_df.head(num_subjects)
             genetic_data_output.append(temp_output)
 
             del genetic_df
